/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  Copyright (C) 2003 Takuro Ashie
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2, or (at your option)
 *  any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  $Id: kz-bookmark-action.c 3189 2007-04-14 15:13:41Z kous $
 */

#include "kz-bookmark-action.h"

G_DEFINE_TYPE(KzBookmarkAction, kz_bookmark_action, GTK_TYPE_ACTION)

static void
kz_bookmark_action_class_init (KzBookmarkActionClass *klass)
{
}

static void
kz_bookmark_action_init (KzBookmarkAction *action)
{
}
